@@ -739,6 +739,7 @@ class gnuplotlib:
         self.plotOptions      = _dictDeUnderscore(plotOptions)
         self.t0               = time.time()
         self.checkpoint_stuck = False
+        self.sync_count       = 1
 
         plotOptionsCmds = self._getPlotOptionsCmds()
 
@@ -814,7 +815,7 @@ class gnuplotlib:
                 if isinstance(self.plotOptions[setunset], (list, tuple)):
                     cmds += [ setunset + ' ' + setting for setting in self.plotOptions[setunset] ]
                 else:
-                    cmds.append(self.plotOptions[setunset])
+                    cmds.append(setunset + ' ' + self.plotOptions[setunset])
 
         # set the plot bounds
 
@@ -1004,7 +1005,13 @@ defaults are acceptable, use 'hardcopy' only, otherwise use 'terminal' and
     # I test the plot command by making a dummy plot with the test command.
     def _testPlotcmd(self, cmd, data):
 
-        self._printGnuplotPipe( "set output\n" )
+        # I don't actually want to see the plot, I just want to make sure that
+        # no errors are thrown. I thus send the output to /dev/null. Note that I
+        # never actually read stdout, so if this test plot goes to the default
+        # stdout output, then eventually the buffer fills up and gnuplot blocks.
+        # So keep it going to /dev/null, or make sure to read the test plot from
+        # stdout
+        self._printGnuplotPipe( "set output '/dev/null'\n" )
         self._printGnuplotPipe( "set terminal dumb\n" )
 
         # I send a test plot command. Gnuplot implicitly uses && if multiple
@@ -1034,7 +1041,8 @@ defaults are acceptable, use 'hardcopy' only, otherwise use 'terminal' and
         # yet arrived. I thus print out a checkpoint message and keep reading the
         # child's STDERR pipe until I get that message back. Any errors would have
         # been printed before this
-        checkpoint = "xxxxxxx Syncronizing gnuplot i/o xxxxxxx"
+        checkpoint = "gpsync{}xxx".format(self.sync_count)
+        self.sync_count += 1
 
         self._printGnuplotPipe( 'print "{}"\n'.format(checkpoint) )
 
@@ -1143,7 +1151,7 @@ and/or gnuplot itself. Please report this as a gnuplotlib bug''')
     def _logEvent(self, event):
 
         # only log when asked
-        if not 'log' in self.plotOptions:
+        if not self._activePlotOption('log'):
             return
 
         t = time.time() - self.t0
